@@ -59,7 +59,7 @@ case "$switch" in
        echo -n $msg_press_enter_to_continue
        read
        echo "$msg_delimiter_star_line"
-       drbl-live.sh --prepare-ocsroot --skip-pause-in-the-end start
+       drbl-live.sh --prepare-ocsroot --skip-pause-in-the-end --no-prompt-drbl-live start
      fi
 
      echo "$msg_delimiter_star_line"
